==> proxysql2_2.4.4.tar.xz: civetweb-1.11/docs/README.md <==
![CivetWeb](https://raw.github.com/civetweb/civetweb/master/resources/civetweb_64x64.png "CivetWeb") CivetWeb
=======

CivetWeb is an easy to use, powerful, C/C++ embeddable web server with optional CGI, SSL and Lua support.

CivetWeb can be used by developers as a library, to add web server functionality to an existing application.
CivetWeb uses an [MIT license](https://github.com/civetweb/civetweb/blob/master/LICENSE.md).

It can also be used by end users as a stand-alone web server. It is available as single executable, no installation is required.

The current stable version is 1.10 - [release notes](https://github.com/civetweb/civetweb/blob/master/RELEASE_NOTES.md)


End users can download CivetWeb at SourceForge
[https://sourceforge.net/projects/civetweb/](https://sourceforge.net/projects/civetweb/)

Developers can contribute to CivetWeb via GitHub
[https://github.com/civetweb/civetweb](https://github.com/civetweb/civetweb)

Trouble tickets should be filed on GitHub
[https://github.com/civetweb/civetweb/issues](https://github.com/civetweb/civetweb/issues)

Announcements are at Google Groups
[https://groups.google.com/d/forum/civetweb](https://groups.google.com/d/forum/civetweb)

While older support question and discussion threads have been at [Google groups](https://groups.google.com/d/forum/civetweb), most newer ones are [GitHub issues](https://github.com/civetweb/civetweb/issues).

Source releases can be found on GitHub
[https://github.com/civetweb/civetweb/releases](https://github.com/civetweb/civetweb/releases)

CivetWeb is free of charge, however, donations for maintenance are welcome:
[![Donate](https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif)](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=88ZLXZ6U77GJU)


Documentation
---------------

- [Installing.md](Installing.md) - Install Guide (for end users using pre-built binaries)
- [UserManual.md](UserManual.md) - End User Guide
- [Building.md](Building.md) - Building the Server (quick start guide)
- [Embedding.md](Embedding.md) - Embedding (how to add HTTP support to an existing application)
- [OpenSSL.md](OpenSSL.md) - Adding HTTPS (SSL/TLS) support using OpenSSL.
- [API documentation](api) - Additional documentation on the civetweb application programming interface ([civetweb.h](https://github.com/civetweb/civetweb/blob/master/include/civetweb.h)).

[Authors](https://github.com/civetweb/civetweb/blob/master/CREDITS.md)

==> proxysql2_2.5.1.tar.xz: civetweb-1.15/docs/README.md <==
![CivetWeb](https://raw.github.com/civetweb/civetweb/master/resources/civetweb_64x64.png "CivetWeb") CivetWeb
=======

CivetWeb is an easy to use, powerful, C/C++ embeddable web server with optional CGI, SSL and Lua support.

CivetWeb can be used by developers as a library, to add web server functionality to an existing application.
CivetWeb uses an [MIT license](https://github.com/civetweb/civetweb/blob/master/LICENSE.md).

It can also be used by end users as a stand-alone web server. It is available as single executable, no installation is required.

To find the latest stable release, visit [https://github.com/civetweb/civetweb/releases](https://github.com/civetweb/civetweb/releases).
A list of selected changes can be found in the [release notes](https://github.com/civetweb/civetweb/blob/master/RELEASE_NOTES.md).

End users can download CivetWeb at SourceForge
[https://sourceforge.net/projects/civetweb/](https://sourceforge.net/projects/civetweb/)

Developers can contribute to CivetWeb via GitHub
[https://github.com/civetweb/civetweb](https://github.com/civetweb/civetweb)

Trouble tickets should be filed on GitHub
[https://github.com/civetweb/civetweb/issues](https://github.com/civetweb/civetweb/issues)

New releases are announced at Google Groups
[https://groups.google.com/d/forum/civetweb](https://groups.google.com/d/forum/civetweb)

Formerly some support question and discussion threads have been at [Google groups](https://groups.google.com/d/forum/civetweb).
Recent questions and discussions use [GitHub issues](https://github.com/civetweb/civetweb/issues).

Source releases can be found on GitHub
[https://github.com/civetweb/civetweb/releases](https://github.com/civetweb/civetweb/releases)

A security policy can be found in [SECURITY.md](https://github.com/civetweb/civetweb/blob/master/SECURITY.md).

CivetWeb is free of charge, however, donations for maintenance are welcome:
[![Donate](https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif)](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=88ZLXZ6U77GJU)


Documentation
---------------

- [Installing.md](Installing.md) - Install Guide (for end users using pre-built binaries)
- [UserManual.md](UserManual.md) - End User Guide
- [Building.md](Building.md) - Building the Server (quick start guide)
- [Embedding.md](Embedding.md) - Embedding (how to add HTTP support to an existing application)
- [OpenSSL.md](OpenSSL.md) - Adding HTTPS (SSL/TLS) support using OpenSSL.
- [API documentation](api) - Additional documentation on the civetweb application programming interface ([civetweb.h](https://github.com/civetweb/civetweb/blob/master/include/civetweb.h)).

[Authors](https://github.com/civetweb/civetweb/blob/master/CREDITS.md)
